@@ -244,7 +244,7 @@ class PerfProcess(Generic[Alpha]):
 
     def _ok(self, stdout: str) \
             -> Result[Alpha, CalledProcessError]:
-        return ResultOk(stdout)
+        raise NotImplementedError('PerfProcess._ok')
 
     def _error(self, returncode: int, stderr: str) \
             -> Result[Alpha, CalledProcessError]:
@@ -263,14 +263,26 @@ class PerfProcess(Generic[Alpha]):
                             label, self._perfindex, run_time,
                             uom = 's', limit_min = 0)
                 else:
-                    self._perflog.add(label, run_time, uio = 's', limit_min = 0)
+                    self._perflog.add(label, run_time, uom = 's', limit_min = 0)
             if returncode == 0:
                 self._result = self._ok(stdout)
             else:
                 self._result = self._error(returncode, stderr)
         return self._result
 
-class ArcsubProcess(PerfProcess):
+class PerfProcessNone(PerfProcess[None]):
+
+    def _ok(self, stdout: str) \
+            -> Result[Alpha, CalledProcessError]:
+        return ResultOk(None)
+
+class PerfProcessStr(PerfProcess[None]):
+
+    def _ok(self, stdout: str) \
+            -> Result[Alpha, CalledProcessError]:
+        return ResultOk(stdout)
+
+class ArcsubProcess(PerfProcessStr):
     program = 'arcsub'
 
     def __init__(
@@ -300,12 +312,12 @@ class ArcsubProcess(PerfProcess):
         if loglevel:
             args += ['-d', loglevel]
         if submissioninterface:
-            args += ['-S', submissioninterface]
+            args += ['--submission-endpoint-type', submissioninterface]
         if infointerface:
-            args += ['-I', infointerface]
-        PerfProcess.__init__(self, args, perflog, perfindex)
+            args += ['--info-endpoint-type', infointerface]
+        super().__init__(args, perflog, perfindex)
 
-class ArcgetProcess(PerfProcess):
+class ArcgetProcess(PerfProcessStr):
     program = 'arcget'
 
     def __init__(
@@ -319,9 +331,9 @@ class ArcgetProcess(PerfProcess):
             args += ['-t', _time_arg(timeout)]
         if not top_output_dir is None:
             args += ['-D', top_output_dir]
-        PerfProcess.__init__(self, args, perflog, ce_host)
+        super().__init__(args, perflog, ce_host)
 
-class ArckillProcess(PerfProcess):
+class ArckillProcess(PerfProcessNone):
     program = 'arckill'
 
     def __init__(
@@ -333,9 +345,9 @@ class ArckillProcess(PerfProcess):
         args = [job_id]
         if not timeout is None:
             args += ['-t', _time_arg(timeout)]
-        PerfProcess.__init__(self, args, perflog, ce_host)
+        super().__init__(args, perflog, ce_host)
 
-class ArccleanProcess(PerfProcess):
+class ArccleanProcess(PerfProcessNone):
     program = 'arcclean'
 
     def __init__(
@@ -348,9 +360,9 @@ class ArccleanProcess(PerfProcess):
             args += ['-t', _time_arg(timeout)]
         if force:
             args.append('-f')
-        PerfProcess.__init__(self, args, perflog, ce_host)
+        super().__init__(args, perflog, ce_host)
 
-class ArcrmProcess(PerfProcess):
+class ArcrmProcess(PerfProcessNone):
     program = 'arcrm'
 
     def __init__(
@@ -363,9 +375,9 @@ class ArcrmProcess(PerfProcess):
             args += ['-t', _time_arg(timeout)]
         if force:
             args.append('-f')
-        PerfProcess.__init__(self, args, perflog, se_host)
+        super().__init__(args, perflog, se_host)
 
-class ArccpProcess(PerfProcess):
+class ArccpProcess(PerfProcessNone):
     program = 'arccp'
 
     def __init__(
@@ -382,7 +394,7 @@ class ArccpProcess(PerfProcess):
             args += ['-t', _time_arg(timeout)]
         if not transfer:
             args.append('-T')
-        PerfProcess.__init__(self, args, perflog, se_host)
+        super().__init__(args, perflog, se_host)
 
 def _str_or_na(arg: str) -> Optional[str]:
     if arg == '(n/a)':
@@ -417,7 +429,7 @@ class ArclsProcess(PerfProcess[List[ArclsEntry]]):
         args = ['-l', url]
         if not timeout is None:
             args += ['-t', _time_arg(timeout)]
-        PerfProcess.__init__(self, args, perflog, se_host)
+        super().__init__(args, perflog, se_host)
 
     def _ok(self, stdout: str) -> Result[List[ArclsEntry], CalledProcessError]:
         entries = []
@@ -447,37 +459,39 @@ class ArclsProcess(PerfProcess[List[ArclsEntry]]):
             entries.append(ArclsEntry(**kwargs))
         return ResultOk(entries)
 
+# TODO: Typing for *args and **kwargs.
+
 class ArcClient:
 
     def __init__(self, perflog: Optional[NagiosPerflog] = None):
         self._perflog = perflog
 
-    def arcsub(self, *args, **kwargs) -> str:
+    def arcsub(self, *args, **kwargs) -> Result[str, CalledProcessError]:
         kwargs['perflog'] = self._perflog
         with ArcsubProcess(*args, **kwargs) as process:
             return process.communicate()
 
-    def arcget(self, *args, **kwargs) -> str:
+    def arcget(self, *args, **kwargs) -> Result[str, CalledProcessError]:
         kwargs['perflog'] = self._perflog
         with ArcgetProcess(*args, **kwargs) as process:
             return process.communicate()
 
-    def arcrm(self, *args, **kwargs) -> str:
+    def arcrm(self, *args, **kwargs) -> Result[None, CalledProcessError]:
         kwargs['perflog'] = self._perflog
         with ArcrmProcess(*args, **kwargs) as process:
             return process.communicate()
 
-    def arcclean(self, *args, **kwargs) -> str:
+    def arcclean(self, *args, **kwargs) -> Result[None, CalledProcessError]:
         kwargs['perflog'] = self._perflog
         with ArccleanProcess(*args, **kwargs) as process:
             return process.communicate()
 
-    def arckill(self, *args, **kwargs) -> str:
+    def arckill(self, *args, **kwargs) -> Result[None, CalledProcessError]:
         kwargs['perflog'] = self._perflog
         with ArckillProcess(*args, **kwargs) as process:
             return process.communicate()
 
-    def arccp(self, *args, **kwargs) -> str:
+    def arccp(self, *args, **kwargs) -> Result[None, CalledProcessError]:
         kwargs['perflog'] = self._perflog
         with ArccpProcess(*args, **kwargs) as process:
             return process.communicate()
